/** \file app_interrogate.h */

// Copyright (C) 2021-2022 Sanford Rockowitz <rockowitz@minsoft.com>
// SPDX-License-Identifier: GPL-2.0-or-later

#ifndef APP_INTERROGATE_H_
#define APP_INTERROGATE_H_

#include "cmdline/parsed_cmd.h"

void app_interrogate(Parsed_Cmd * parsed_cmd);
void init_app_interrogate();

#endif /* APP_INTERROGATE_H_ */
